@@ -26,18 +26,11 @@ namespace OpenQA.Selenium.BiDi.Communication.Json.Converters;
 
 internal class RequestConverter : JsonConverter<Request>
 {
-    private readonly BiDi _bidi;
-
-    public RequestConverter(BiDi bidi)
-    {
-        _bidi = bidi;
-    }
-
     public override Request? Read(ref Utf8JsonReader reader, Type typeToConvert, JsonSerializerOptions options)
     {
         var id = reader.GetString();
 
-        return new Request(_bidi, id!);
+        return new Request(id!);
     }
 
     public override void Write(Utf8JsonWriter writer, Request value, JsonSerializerOptions options)
