@@ -22,6 +22,6 @@ using OpenQA.Selenium.BiDi.Communication;
 namespace OpenQA.Selenium.BiDi.Modules.Browser;
 
 internal class CreateUserContextCommand()
-    : Command<CommandParameters>(CommandParameters.Empty, "browser.createUserContext");
+    : Command<CommandParameters, UserContextInfo>(CommandParameters.Empty, "browser.createUserContext");
 
 public record CreateUserContextOptions : CommandOptions;
