@@ -22,7 +22,7 @@ using OpenQA.Selenium.BiDi.Communication;
 namespace OpenQA.Selenium.BiDi.Modules.BrowsingContext;
 
 internal class ActivateCommand(ActivateCommandParameters @params)
-    : Command<ActivateCommandParameters>(@params, "browsingContext.activate");
+    : Command<ActivateCommandParameters, EmptyResult>(@params, "browsingContext.activate");
 
 internal record ActivateCommandParameters(BrowsingContext Context) : CommandParameters;
 
