@@ -22,7 +22,7 @@ using OpenQA.Selenium.BiDi.Communication;
 namespace OpenQA.Selenium.BiDi.Modules.BrowsingContext;
 
 internal class CloseCommand(CloseCommandParameters @params)
-    : Command<CloseCommandParameters>(@params, "browsingContext.close");
+    : Command<CloseCommandParameters, EmptyResult>(@params, "browsingContext.close");
 
 internal record CloseCommandParameters(BrowsingContext Context, bool? PromptUnload) : CommandParameters;
 
