@@ -23,6 +23,6 @@ using System.Collections.Generic;
 namespace OpenQA.Selenium.BiDi.Modules.Script;
 
 internal class DisownCommand(DisownCommandParameters @params)
-    : Command<DisownCommandParameters>(@params, "script.disown");
+    : Command<DisownCommandParameters, EmptyResult>(@params, "script.disown");
 
 internal record DisownCommandParameters(IEnumerable<Handle> Handles, Target Target) : CommandParameters;
