@@ -22,7 +22,7 @@ using OpenQA.Selenium.BiDi.Communication;
 namespace OpenQA.Selenium.BiDi.Modules.Script;
 
 internal class RemovePreloadScriptCommand(RemovePreloadScriptCommandParameters @params)
-    : Command<RemovePreloadScriptCommandParameters>(@params, "script.removePreloadScript");
+    : Command<RemovePreloadScriptCommandParameters, EmptyResult>(@params, "script.removePreloadScript");
 
 internal record RemovePreloadScriptCommandParameters(PreloadScript Script) : CommandParameters;
 
